=======================
Jupyter User Interfaces
=======================

The Jupyter user interfaces offer a foundation of interactive computing
environments where scientific computing, data science, and analytics can be
performed using a wide range of programming languages.

.. glossary::

    `JupyterLab <https://jupyterlab.readthedocs.io/en/latest/>`__
        Advanced web-based application for authoring documents that combine live-code
        with narrative text, equations and visualizations.
        `Documentation <https://jupyterlab.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyterlab/jupyterlab>`__

    `Jupyter Notebook <https://jupyter-notebook.readthedocs.io/en/latest/>`__
        A web-based application for authoring documents that combine live-code
        with narrative text, equations and visualizations.
        `Documentation <https://jupyter-notebook.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/notebook>`__

    `Jupyter Desktop <https://github.com/jupyterlab/jupyterlab-desktop>`__
        Desktop application based on JupyterLab for authoring documents that combine live-code
        with narrative text, equations and visualizations.
        `Repo <https://github.com/jupyterlab/jupyterlab-desktop>`__

    `JupyterLite <https://jupyterlite.readthedocs.io/en/latest/>`__
        Installation-free application based on JupyterLab for authoring documents that combine live-code
        with narrative text, equations and visualizations.
        `Documentation <https://jupyterlite.readthedocs.io/en/latest/>`__
        `Repo <https://github.com/jupyterlite/jupyterlite>`__

    `Jupyter Console <https://jupyter-console.readthedocs.io/en/latest/>`__
        Terminal based console for interactive computing.
        `Documentation <https://jupyter-console.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/jupyter_console>`__

    `Jupyter QtConsole <https://jupyter.org/qtconsole/stable/>`__
        Qt application for interactive computing with rich output.
        `Documentation <https://jupyter.org/qtconsole/stable/>`__ |
        `Repo <https://github.com/jupyter/qtconsole>`__
